@@ -401,10 +401,6 @@ class cardScorer(Base,Specials,TransformerMixin):
             + None,保证数据默认
             + list=[value1,value2,...],数据中所有列的值在[value1,value2,...]中都会被替换，字符被替换为'missing',数值被替换为np.nan
             + dict={col_name1:[value1,value2,...],...},数据中指定列替换，被指定的列的值在[value1,value2,...]中都会被替换，字符被替换为'missing',数值被替换为np.nan
-        dtype,可选'float32'与'float64',转换最终评分数据为np.float32/np.float64格式，breaks也会以np.float32/np.float64格式分段数据
-            + 模块会使用varbin中的breaks分段数据，其本身为np.float64，因此fit中的数据的number列也必须为float64,否则会因为格式不一致产生精度问题
-            + 若fit中的数据的number列为float32型，则请设定为float32以保证不因格式不一致而产生精度问题
-            + 请不要在原始数据中共用不同的数值精度格式，例如float32与float64共用，int32与int64共用...，请使用bm.dtypeAllocator统一建模数据的格式
         n_jobs=1,并行数量 
         verbose=0,并行信息输出等级  
             
@@ -415,7 +411,7 @@ class cardScorer(Base,Specials,TransformerMixin):
     ''' 
     
     def __init__(self,logit_model,varbin,odds0=1/100,pdo=50,points0=600,digit=0,special_values=None,
-                 check_na=True,dtype='float64',n_jobs=1,verbose=0):
+                 check_na=True,n_jobs=1,verbose=0):
        
         self.logit_model=logit_model
         self.varbin=varbin
@@ -424,7 +420,6 @@ class cardScorer(Base,Specials,TransformerMixin):
         self.points0=points0
         self.digit=digit
         self.special_values=special_values
-        self.dtype=dtype
         self.check_na=check_na
         self.n_jobs=n_jobs
         self.verbose=verbose
@@ -459,7 +454,6 @@ class cardScorer(Base,Specials,TransformerMixin):
     
     def transform(self,X,y=None):
         
-        self._check_param_dtype(self.dtype)
         self._check_is_fitted()
         self._check_X(X)
         
@@ -467,7 +461,7 @@ class cardScorer(Base,Specials,TransformerMixin):
 
         p=Parallel(n_jobs=n_jobs,verbose=self.verbose)
             
-        res=p(delayed(self._points_map)(X[key],self.scorecard[key],self.check_na,self.special_values,self.dtype) 
+        res=p(delayed(self._points_map)(X[key],self.scorecard[key],self.check_na,self.special_values) 
                               for key in self.columns)
             
         score=pd.concat({col:col_points for col,col_points in res},axis=1)
@@ -508,7 +502,7 @@ class cardScorer(Base,Specials,TransformerMixin):
         return a,b
     
     
-    def _points_map(self,col,bin_df,check_na=True,special_values=None,dtype='float64'):
+    def _points_map(self,col,bin_df,check_na=True,special_values=None):
         
         col=self._sp_replace_single(col,self._check_spvalues(col.name,special_values),fill_num=np.finfo(np.float32).max,fill_str='special')
     
@@ -526,17 +520,17 @@ class cardScorer(Base,Specials,TransformerMixin):
             
             if special_values:
                 
-                breaks_cut=breaks+[np.finfo(np.float32).max] if dtype=='float64' else np.float32(breaks+[np.finfo(np.float32).max]).tolist()
+                breaks_cut=breaks+[np.finfo(np.float32).max]
                 
-                col_points=pd.cut(col,[-np.inf]+breaks_cut+[np.inf],labels=points+[points_sp],right=False,ordered=False).astype(dtype)
+                col_points=pd.cut(col,[-np.inf]+breaks_cut+[np.inf],labels=points+[points_sp],right=False,ordered=False).astype('float64')
                 
                 col_points=col_points.fillna(points_nan)                
 
             else:
                 
-                breaks_cut=breaks if dtype=='float64' else np.float32(breaks).tolist()            
+                breaks_cut=breaks
     
-                col_points=pd.cut(col,[-np.inf]+breaks_cut+[np.inf],labels=points,right=False,ordered=False).astype(dtype)
+                col_points=pd.cut(col,[-np.inf]+breaks_cut+[np.inf],labels=points,right=False,ordered=False).astype('float64')
                 
                 col_points=col_points.fillna(points_nan)                
             
@@ -566,7 +560,7 @@ class cardScorer(Base,Specials,TransformerMixin):
             
             breaks_to_points=dict(zip(breaks,points))
             
-            col_points=col.map(raw_to_breaks).map(breaks_to_points).astype(dtype)
+            col_points=col.map(raw_to_breaks).map(breaks_to_points).astype('float64')
             
         else:
             
