@@ -27,10 +27,6 @@ def test_dtStandardization():
     res=dtStandardization(id_col=['a'],col_rm='b').fit_transform(dt)
     assert res.columns.size==0
     
-    res=dtStandardization(col_rm='b',downcast=True).fit_transform(dt)
-    assert all(np.equal(res.columns,['a'])) 
-    assert res.dtypes['a']==np.dtype('float32')
-    
     res=dtStandardization(id_col=['a'],drop_dup=False).fit_transform(dt)
     assert all(np.equal(res.columns,['b','b'])) 
     assert all(np.equal(res.index,[1,2,2])) 
@@ -40,7 +36,7 @@ def test_dtStandardization():
 def test_dtypeAllocator():
     
     dt=pd.DataFrame(
-        {'a':[1,2,3],'b':[1,2,3],
+        {'a':[1,2,3],'b':[1.,2.,3.],
          'c':['2021-09-01','2022-08-01','2011-12-11'],
          'd':[True,True,False],
          'e':[pd.to_timedelta('4 days'),pd.to_timedelta('5 days'),pd.to_timedelta('6 days')],
@@ -48,9 +44,9 @@ def test_dtypeAllocator():
          }
         )
     
-    res=dtypeAllocator({'int':['f'],'float':['a','d'],'str':['b'],'date':['c'],'tdiff':['e']}).fit_transform(dt)
+    res=dtypeAllocator({'float':['a','d','f'],'str':['b'],'date':['c'],'tdiff':['e']}).fit_transform(dt)
     
-    assert all(np.equal(res.dtypes.tolist(),[np.dtype('int64'),
+    assert all(np.equal(res.dtypes.tolist(),[np.dtype('float64'),
                                              np.dtype('float64'),
                                              np.dtype('float64'), 
                                              np.dtype('O'),
@@ -59,24 +55,26 @@ def test_dtypeAllocator():
     
     res=dtypeAllocator().fit_transform(dt)
     
-    assert all(np.equal(res.dtypes.tolist(),[np.dtype('int64'),
-                                             np.dtype('int64'),
-                                             np.dtype('int64'), 
-                                             np.dtype('int64'),
+    assert all(np.equal(res.dtypes.tolist(),[np.dtype('float64'),
+                                             np.dtype('float64'),
+                                             np.dtype('float64'), 
+                                             np.dtype('float64'),
                                              np.dtype('O'),
                                              np.dtype('float64')]))   
     
-    res=dtypeAllocator({'int':['f'],'float':['a','d'],'str':['b'],'date':['c'],'tdiff':['e']},dtype_num='32',drop_date=True,precision=3).fit_transform(dt)
-    
-    assert all(np.equal(res.dtypes.tolist(),[np.dtype('int32'),
-                                             np.dtype('float32'),
-                                             np.dtype('float32'), 
-                                             np.dtype('O'),
-                                             np.dtype('float32')]))
-    
+    res=dtypeAllocator({'int':['f'],'float':['a','d'],'str':['b'],'date':['c'],'tdiff':['e']},drop_date=True).fit_transform(dt)
     assert 'c' not in res.columns
     
     
+    res=dtypeAllocator(col_rm=['a','b','c','d','e','f']).fit_transform(dt)
+    assert all(np.equal(res.dtypes.tolist(),[np.dtype('int64'),
+                                             np.dtype('float64'),
+                                             np.dtype('O'), 
+                                             np.dtype('bool'),
+                                             np.dtype('<m8[ns]'),
+                                             np.dtype('int64')]))   
+    
+    
 def test_nanTransformer():
     
     dt=pd.DataFrame(
@@ -110,12 +108,6 @@ def test_nanTransformer():
     assert all(np.equal(res['b_isnan'],[1,1,1,0]))
     
     
-    res=nanTransformer(method=('knn','most_frequent'),fill_value=(np.nan, 'missing'),dtype_num='float32').fit_transform(dt)  
-    assert all(np.equal(res['a'],[1.,1.,1.,1.]))
-    assert res['a'].dtype==np.dtype('float32')
-    
-    
-
 def test_outliersTransformer():
     
     dt=pd.DataFrame(
@@ -138,7 +130,5 @@ def test_outliersTransformer():
     res=outliersTransformer(method='fill').fit_transform(dt)
     
     assert(res.loc[0,'a']==-123.75)
-    assert(res.loc[99,'a']==222.75)
-    
-    
+    assert(res.loc[99,'a']==222.75)    
     
\ No newline at end of file
